@@ -48,3 +48,23 @@ class InvocationMessage(BaseHeadersMessage):
         self.invocation_id = invocation_id
         self.target = target
         self.arguments = arguments
+
+    def __repr__(self):
+        return "InvocationMessage: invocation_id {0}, target {1}, arguments {2}".format(self.invocation_id, self.target, self.arguments)
+
+
+class InvocationClientStreamMessage(BaseHeadersMessage):
+    def __init__(
+            self,
+            headers,
+            stream_ids,
+            target,
+            arguments):
+        super(InvocationClientStreamMessage, self).__init__(1, headers)
+        self.target = target
+        self.arguments = arguments
+        self.stream_ids = stream_ids
+
+    def __repr__(self):
+        return "InvocationMessage: stream_ids {0}, target {1}, arguments {2}".format(
+            self.stream_ids, self.target, self.arguments)
